@@ -26,11 +26,11 @@
 #define DH_BITS 1024
 
 /* These are global */
-gnutls_certificate_credentials x509_cred;
+gnutls_certificate_credentials_t x509_cred;
 
-gnutls_session initialize_tls_session()
+gnutls_session_t initialize_tls_session()
 {
-   gnutls_session session;
+   gnutls_session_t session;
 
    gnutls_init(&session, GNUTLS_SERVER);
 
@@ -50,7 +50,7 @@ gnutls_session initialize_tls_session()
    return session;
 }
 
-static gnutls_dh_params dh_params;
+static gnutls_dh_params_t dh_params;
 
 static int generate_dh_params(void) {
 
@@ -73,7 +73,7 @@ int main()
    struct sockaddr_in sa_cli;
    int client_len;
    char topbuf[512];
-   gnutls_session session;
+   gnutls_session_t session;
    char buffer[MAX_BUF + 1];
    int optval = 1;
 
@@ -124,7 +124,7 @@ int main()
              inet_ntop(AF_INET, &sa_cli.sin_addr, topbuf,
                        sizeof(topbuf)), ntohs(sa_cli.sin_port));
 
-      gnutls_transport_set_ptr( session, (gnutls_transport_ptr)sd);
+      gnutls_transport_set_ptr( session, (gnutls_transport_ptr_t)sd);
       ret = gnutls_handshake( session);
       if (ret < 0) {
          close(sd);
