@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000,2001,2002,2003 Nikos Mavroyanopoulos
  *  Copyright (C) 2004 Free Software Foundation
+ *  Copyright (C) 2000,2001,2002,2003 Nikos Mavroyanopoulos
  *
  *  This file is part of GNUTLS.
  *
@@ -38,7 +38,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "1.1.13"
+#define LIBGNUTLS_VERSION "1.1.14"
 
 #ifndef HAVE_SIZE_T
 # define HAVE_SIZE_T
@@ -405,19 +405,20 @@ int gnutls_certificate_set_x509_crl(gnutls_certificate_credentials_t res,
     gnutls_x509_crl_t* crl_list, int crl_list_size);
 
 
-/* global state functions 
+/* global state functions
  */
 int gnutls_global_init(void);
 void gnutls_global_deinit(void);
 
 typedef void* (*gnutls_alloc_function)(size_t);
 typedef void* (*gnutls_calloc_function)(size_t, size_t);
+typedef int (*gnutls_is_secure_function)(const void*);
 typedef void (*gnutls_free_function)(void*);
 typedef void* (*gnutls_realloc_function)(void*, size_t);
 
-void gnutls_global_set_mem_functions( 
+void gnutls_global_set_mem_functions(
     gnutls_alloc_function, gnutls_alloc_function,
-    int (*gnutls_is_secure_func)(const void*), gnutls_realloc_function,
+    gnutls_is_secure_function, gnutls_realloc_function,
     gnutls_free_function);
 
 /* For use in callbacks */
